"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const path = require("path");
var sematicAnalyser = require('../Semantic Analyser/analyser');
var parser = require('../Parser/validator');
var generator = require('../Machines/CompilerUtils/machineGenerator');
const fs = require("fs");
class Rebuild extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Rebuild);
        const df = flags.dialogflow || false;
        let cwd = process.cwd();
        try {
            let atmtFile = path.join(cwd, 'bot.json');
            let atmtFileJson = JSON.parse(fs.readFileSync(atmtFile, 'utf-8'));
            let errors = parser(atmtFileJson)['errors'];
            if (errors.length > 0)
                throw new Error(JSON.stringify(errors, null, '\t'));
            let syntaxTree = sematicAnalyser(atmtFileJson);
            generator.update(syntaxTree, flags);
            this.log('Done applying changes from bot.json');
        }
        catch (err) {
            this.error(err);
        }
    }
}
Rebuild.description = 'apply changes in bot.atmt.json, preserve function implementations in *Impl.js files';
Rebuild.examples = [
    `$ botc rebuild`,
];
Rebuild.flags = {
    dialogflow: command_1.flags.boolean({ char: 'd', description: 'use dialogflow' })
};
Rebuild.args = [];
exports.default = Rebuild;
